macro_rules! chat {
($player:expr,$($arg:tt)+) => { ... };
}Expand description
A log macro for chat messages, provide first the player name, and then the format.
macro_rules! chat {
($player:expr,$($arg:tt)+) => { ... };
}A log macro for chat messages, provide first the player name, and then the format.