macro_rules! command {
($player:expr,$($arg:tt)+) => { ... };
}Expand description
A log macro for commands, provide first the player name, and then the format.
macro_rules! command {
($player:expr,$($arg:tt)+) => { ... };
}A log macro for commands, provide first the player name, and then the format.